==> r-antd-0.1.30.tgz: package/es/r-table/r-table.js <==
import _slicedToArray from "babel-runtime/helpers/slicedToArray";
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
import _typeof from "babel-runtime/helpers/typeof";
import _extends from "babel-runtime/helpers/extends";
var __rest = this && this.__rest || function (s, e) {
    var t = {};
    for (var p in s) {
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
    }if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
        if (e.indexOf(p[i]) < 0) t[p[i]] = s[p[i]];
    }return t;
};
import React, { Component } from "react";
import { findDOMNode } from "react-dom";
import omit from "lodash.omit";
import { Table } from "antd";
import { wrapTooltip, insertIndexAsKey } from "./../__util";
var hasFixedColumn = function hasFixedColumn() {
    var columns = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    return columns.some(function (_ref) {
        var fixed = _ref.fixed;
        return !!fixed;
    });
};
var mapColumns = function mapColumns() {
    var columns = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    return columns.map(function (column) {
        var _column$tooltip = column.tooltip,
            tooltip = _column$tooltip === undefined ? false : _column$tooltip,
            renderTooltip = column.renderTooltip,
            maxWidth = column.maxWidth,
            width = column.width,
            render = column.render;

        if (!tooltip) return column;
        if (!width && !maxWidth) {
            throw new Error("Ops, width or maxWidth is required when you need wrap tooltip!");
        }
        var nextColumn = _extends({}, column, { render: wrapTooltip({
                maxWidth: Number(maxWidth || width) - 20,
                preRender: render,
                renderTooltip: renderTooltip
            }) });
        return omit(nextColumn, ["maxWidth", "tooltip", "renderTooltip"]);
    });
};
// const removeUnnecessaryColumnWidth = (columns: any[] = []) => {
//   if (!hasFixedColumn(columns)) return columns;
//   return columns.map(column => {
//     if ("fixed" in column) {
//       return column;
//     }
//     return omit(column, ["width"]);
//   });
// };
var scrollX = function scrollX(props) {
    var _props$columns = props.columns,
        columns = _props$columns === undefined ? [] : _props$columns,
        rowSelection = props.rowSelection,
        expandedRowRender = props.expandedRowRender;
    // const hasFixedColumn = columns.some(({ fixed }) => !!fixed);

    if (!hasFixedColumn(columns)) return;
    var hasCheckbox = false;
    if ((typeof rowSelection === "undefined" ? "undefined" : _typeof(rowSelection)) == "object" && rowSelection) hasCheckbox = true;
    var initalWidth = 0;
    if (hasCheckbox) initalWidth += 62;
    if (typeof expandedRowRender == "function") initalWidth += 50;
    var unFixedColumnWidthSum = columns.reduce(function (widthSum, _ref2) {
        var _ref2$width = _ref2.width,
            width = _ref2$width === undefined ? 0 : _ref2$width;
        return widthSum + Number(width);
    }, initalWidth);
    // console.log(unFixedColumnWidthSum);
    return unFixedColumnWidthSum;
};
export var RTable = function (_Component) {
    _inherits(RTable, _Component);

    function RTable() {
        _classCallCheck(this, RTable);

        var _this = _possibleConstructorReturn(this, (RTable.__proto__ || Object.getPrototypeOf(RTable)).apply(this, arguments));

        _this.fixFixedFirstThWidth = function () {
            var tableDomNode = findDOMNode(_this.table);
            var scrollThNodes = tableDomNode.querySelectorAll("div.ant-table-scroll th");
            var fixedHeaderColNodes = tableDomNode.querySelectorAll("div.ant-table-fixed-left div.ant-table-header col");
            var fixedBodyColNodes = tableDomNode.querySelectorAll("div.ant-table-fixed-left div.ant-table-body-inner col");
            var scrollThs = Array.from(scrollThNodes);
            Array.from(fixedHeaderColNodes).forEach(function (fhc, i) {
                fhc.style.width = scrollThs[i].clientWidth + "px";
            });
            Array.from(fixedBodyColNodes).forEach(function (fbc, i) {
                fbc.style.width = scrollThs[i].clientWidth + "px";
            });
        };
        return _this;
    }

    _createClass(RTable, [{
        key: "componentDidMount",
        value: function componentDidMount() {
            this.fixFixedFirstThWidth();
        }
    }, {
        key: "render",
        value: function render() {
            var _this2 = this;

            var _a = this.props,
                _a$fixedMaxWidth = _a.fixedMaxWidth,
                fixedMaxWidth = _a$fixedMaxWidth === undefined ? false : _a$fixedMaxWidth,
                style = _a.style,
                columns = _a.columns,
                pagination = _a.pagination,
                scroll = _a.scroll,
                others = __rest(_a, ["fixedMaxWidth", "style", "columns", "pagination", "scroll"]);
            var rest = others;
            if (!others.rowKey) {
                rest = _extends({}, rest, { dataSource: insertIndexAsKey(others.dataSource) });
            }
            if (!pagination) {
                rest = _extends({}, rest, {
                    pagination: pagination
                });
            }
            var xWidth = scrollX(this.props);
            var defaultStyle = fixedMaxWidth ? { maxWidth: xWidth || "100%" } : {};
            return React.createElement(Table, _extends({ ref: function ref(table) {
                    return _this2.table = table;
                }, style: _extends({}, style, defaultStyle), size: "middle", columns: mapColumns(columns), pagination: _extends({ showSizeChanger: true, pageSizeOptions: ["5", "10", "20", "50", "100", "500", "1000"], showQuickJumper: true, showTotal: function showTotal(total, _ref3) {
                        var _ref4 = _slicedToArray(_ref3, 2),
                            start = _ref4[0],
                            end = _ref4[1];

                        return start + "-" + end + " / " + total;
                    } }, pagination), scroll: _extends({ x: xWidth }, scroll) }, rest));
        }
    }]);

    return RTable;
}(Component);
export default RTable;

==> r-antd-0.1.31.tgz: package/es/r-table/r-table.js <==
import _slicedToArray from "babel-runtime/helpers/slicedToArray";
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
import _typeof from "babel-runtime/helpers/typeof";
import _extends from "babel-runtime/helpers/extends";
var __rest = this && this.__rest || function (s, e) {
    var t = {};
    for (var p in s) {
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
    }if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
        if (e.indexOf(p[i]) < 0) t[p[i]] = s[p[i]];
    }return t;
};
import React, { Component } from "react";
import { findDOMNode } from "react-dom";
import omit from "lodash.omit";
import { Table } from "antd";
import { wrapTooltip, insertIndexAsKey } from "./../__util";
var hasFixedColumn = function hasFixedColumn() {
    var columns = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    return columns.some(function (_ref) {
        var fixed = _ref.fixed;
        return !!fixed;
    });
};
var mapColumns = function mapColumns() {
    var columns = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    return columns.map(function (column) {
        var _column$tooltip = column.tooltip,
            tooltip = _column$tooltip === undefined ? false : _column$tooltip,
            renderTooltip = column.renderTooltip,
            maxWidth = column.maxWidth,
            width = column.width,
            render = column.render;

        if (!tooltip) return column;
        if (!width && !maxWidth) {
            throw new Error("Ops, width or maxWidth is required when you need wrap tooltip!");
        }
        var nextColumn = _extends({}, column, { render: wrapTooltip({
                maxWidth: Number(maxWidth || width) - 20,
                preRender: render,
                renderTooltip: renderTooltip
            }) });
        return omit(nextColumn, ["maxWidth", "tooltip", "renderTooltip"]);
    });
};
var removeColumnFixedProps = function removeColumnFixedProps() {
    var columns = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

    if (!hasFixedColumn(columns)) return columns;
    return columns.map(function (column) {
        if ("fixed" in column) {
            return omit(column, ["fixed"]);
        }
        return column;
    });
};
var scrollX = function scrollX(props) {
    var _props$columns = props.columns,
        columns = _props$columns === undefined ? [] : _props$columns,
        rowSelection = props.rowSelection,
        expandedRowRender = props.expandedRowRender;
    // const hasFixedColumn = columns.some(({ fixed }) => !!fixed);

    if (!hasFixedColumn(columns)) return;
    var hasCheckbox = false;
    if ((typeof rowSelection === "undefined" ? "undefined" : _typeof(rowSelection)) == "object" && rowSelection) hasCheckbox = true;
    var initalWidth = 0;
    if (hasCheckbox) initalWidth += 62;
    if (typeof expandedRowRender == "function") initalWidth += 50;
    var unFixedColumnWidthSum = columns.reduce(function (widthSum, _ref2) {
        var _ref2$width = _ref2.width,
            width = _ref2$width === undefined ? 0 : _ref2$width;
        return widthSum + Number(width);
    }, initalWidth);
    // console.log(unFixedColumnWidthSum);
    return unFixedColumnWidthSum;
};
export var RTable = function (_Component) {
    _inherits(RTable, _Component);

    function RTable() {
        _classCallCheck(this, RTable);

        var _this = _possibleConstructorReturn(this, (RTable.__proto__ || Object.getPrototypeOf(RTable)).apply(this, arguments));

        _this.state = {
            shouldRemoveColumnFixedProps: false
        };
        return _this;
    }

    _createClass(RTable, [{
        key: "componentDidMount",
        value: function componentDidMount() {
            var tableDomNode = findDOMNode(this.table);
            var xWidth = scrollX(this.props) || 0;
            if (tableDomNode.clientWidth - xWidth > 0) {
                this.setState({ shouldRemoveColumnFixedProps: true });
            }
        }
    }, {
        key: "render",
        value: function render() {
            var _this2 = this;

            var _a = this.props,
                _a$fixedMaxWidth = _a.fixedMaxWidth,
                fixedMaxWidth = _a$fixedMaxWidth === undefined ? false : _a$fixedMaxWidth,
                style = _a.style,
                columns = _a.columns,
                scroll = _a.scroll,
                others = __rest(_a, ["fixedMaxWidth", "style", "columns", "scroll"]);var shouldRemoveColumnFixedProps = this.state.shouldRemoveColumnFixedProps;

            var nextColumns = mapColumns(columns);
            if (shouldRemoveColumnFixedProps) {
                nextColumns = removeColumnFixedProps(nextColumns);
            }
            var rest = others;
            if (!others.rowKey) {
                rest = _extends({}, rest, { dataSource: insertIndexAsKey(others.dataSource) });
            }
            // if (!pagination) {
            //   rest = Object.assign({}, rest, {
            //     pagination,
            //   });
            // }
            var xWidth = scrollX(this.props);
            var defaultStyle = fixedMaxWidth ? { maxWidth: xWidth || "100%" } : {};
            return React.createElement(Table, _extends({ ref: function ref(table) {
                    return _this2.table = table;
                }, style: _extends({}, style, defaultStyle), size: "middle", columns: nextColumns, pagination: _extends({ showSizeChanger: true, pageSizeOptions: ["5", "10", "20", "50", "100", "500", "1000"], showQuickJumper: true, showTotal: function showTotal(total, _ref3) {
                        var _ref4 = _slicedToArray(_ref3, 2),
                            start = _ref4[0],
                            end = _ref4[1];

                        return start + "-" + end + " / " + total;
                    } }, rest.pagination), scroll: _extends({ x: xWidth }, scroll) }, rest));
        }
    }]);

    return RTable;
}(Component);
export default RTable;
